// Program version
var versionNum = "1.4.3";

var versionRequest; // for the new version check
var openCommand = null;
var toggleHidden = null;
var openItem = null;
var deleteItem = null;

function load() {
  setupParts();
  document.getElementById("description").innerText = getLocalizedString('Select');
  document.getElementById("dir").setAttribute("label", getLocalizedString('Directories'));
  document.getElementById("hidden").setAttribute("label", getLocalizedString('Hidden'));
  document.getElementById("opendelete").setAttribute("label", getLocalizedString('OpenDelete'));
  document.getElementById("open").setAttribute("label", getLocalizedString('Open'));
  document.getElementById("delete").setAttribute("label", getLocalizedString('Delete'));
  document.getElementById("toggle").innerText =  getLocalizedString('Toggle');
}

//
// Function: remove()
// Called when the widget has been removed from the Dashboard
//
function remove() {
  // Stop any timers to prevent CPU usage
  // Remove any preferences as needed
  // widget.setPreferenceForKey(null, createInstancePreferenceKey("your-key"));
}

//
// Function: hide()
// Called when the widget has been hidden
//
function hide() {
  // Stop any timers to prevent CPU usage
}

//
// Function: show()
// Called when the widget has been shown
//
function show() {
  // Restart any timers that were stopped on hide
}

//
// Function: sync()
// Called when the widget has been synchronized with .Mac
//
function sync() {
  // Retrieve any preference values that you need to be synchronized here
  // Use this for an instance key's value:
  // instancePreferenceValue = widget.preferenceForKey(null, createInstancePreferenceKey("your-key"));
  //
  // Or this for global key's value:
  // globalPreferenceValue = widget.preferenceForKey(null, "your-key");
}

//
// Function: showBack(event)
// Called when the info button is clicked to show the back of the widget
//
// event: onClick event from the info button
//
function showBack(event) {
  window.resizeTo(250, 90);
  var front = document.getElementById("front");
  var back = document.getElementById("back");

  if (window.widget) {
    widget.prepareForTransition("ToBack");
  }

  front.style.display = "none";
  back.style.display = "block";

  document.getElementById("version-label").innerHTML =  getLocalizedString('Version') + versionNum;

  if (window.widget) {
    setTimeout('widget.performTransition();', 0);
  }

  checkForNewVersion();
}

//
// Function: showFront(event)
// Called when the done button is clicked from the back of the widget
//
// event: onClick event from the done button
//
function showFront(event) {
  var front = document.getElementById("front");
  var back = document.getElementById("back");

  if (window.widget) {
    widget.prepareForTransition("ToFront");
  }

  front.style.display="block";
  back.style.display="none";

  window.resizeTo(90, 90);

  if (window.widget) {
    setTimeout('widget.performTransition();', 0);
  }
}

if (window.widget) {
  widget.onremove = remove;
  widget.onhide = hide;
  widget.onshow = show;
  widget.onsync = sync;
}

// function opening the selected directory
function openFolder(event) {
  var directory = event.srcElement.value;
  if (directory == '')
    return;
  document.getElementById('select-menu').selectedIndex = 0;

  if (window.widget) {
    if (directory == "ToggleHidden") {
      toggleHidden = widget.system("/usr/bin/osascript scripts/ToggleFinderHiddenValue.scpt", toggleDone);
    } else if (directory == "Open") {
      widget.openApplication("com.apple.finder"); // show the Finder
      openItem =  widget.system("/usr/bin/open scripts/OpenInvisibleItem.app", openDone);
    } else if (directory == "Delete") {
      widget.openApplication("com.apple.finder"); // show the Finder
      deleteItem =  widget.system("/usr/bin/open scripts/DeleteInvisibleItem.app", deleteDone);
    } else { // it's directory
      openCommand = widget.system("/usr/bin/open " + directory, done);
    }
  }
}

function done() {
  openCommand.close();
  openCommand = null;
  widget.openApplication("com.apple.finder"); // show the Finder
}

function toggleDone() {
  toggleHidden.close();
  toggleHidden = null;
  widget.openApplication("com.apple.finder"); // show the Finder
}

function openDone() {
  openItem.close();
  openItem = null;
}

function deleteDone() {
  deleteItem.close();
  deleteItem = null;
}

/******************/
// Drag and drop code
// This code handles the various drag and drop events
/******************/

// The event handler for the folder/directory drop and hiding.

var currentlyBeingHidden = null;

function dragdrop (event) {
  var uri = null;
  try {
    uri = event.dataTransfer.getData("text/uri-list");	// attempt to load the URL
  } catch (ex) {
  }

    // if the acquisition is successful:
  if (uri) {
    var droppedfilesURI = uri.split("\n");
    var droppedfilesInvisibleURI = [];
    for (var i = 0; i < droppedfilesURI.length; i++) {
      droppedfilesURI[i] = droppedfilesURI[i].toPosixPath();
    }
    for (var i = 0; i < droppedfilesURI.length; i++) {
      currentlyBeingHidden = widget.system("/usr/bin/chflags hidden " + droppedfilesURI[i], doneHiding);
      currentlyBeingHidden.onreaderror = errorHandler;
    }
  }

  event.stopPropagation();
  event.preventDefault();

}

String.prototype.toPosixPath = function() {
  var tmp = unescape(this.substr(this.indexOf("localhost") + 9));
  return tmp.replace(/ /g, "\\ ");
}

function doneHiding() {
  currentlyBeingHidden.close();
  currentlyBeingHidden = null;
  document.getElementById('frontImg').src = "images/Blue_GenericFolder.png";
  widget.openApplication("com.apple.finder");
}

function errorHandler(currentStringOnStderr) {
  currentlyBeingHidden.cancel();
  doneHiding();
}

// The dragenter, dragover, and dragleave functions are implemented but not used.  They
// can be used if you want to change the image when it enters the widget.

function dragenter (event) {
  document.getElementById('frontImg').src = "images/Blue_InvisibleFolder.png";
  event.stopPropagation();
  event.preventDefault();
}

function dragover (event) {
  event.stopPropagation();
  event.preventDefault();
}

function dragleave (event) {
  document.getElementById('frontImg').src = "images/Blue_GenericFolder.png";
  event.stopPropagation();
  event.preventDefault();
}

function goWidgetHome(event) {
  widget.openURL("http://appletree.or.kr/widgets/DirectoryOpener/");
}

// Download version.txt from website and check version numbers
function checkForNewVersion() {
  var versionURL = "http://appletree.or.kr/widgets/DirectoryOpener/version.txt";

  versionRequest = new XMLHttpRequest();
  versionRequest.onload = getVersionNumber;
  versionRequest.open("GET", versionURL);
  versionRequest.setRequestHeader("Cache-Control", "no-cache");
  versionRequest.send(null);
}

// If new version is available, display link and notice
function getVersionNumber() {
  if (versionRequest.readyState == 4 && versionRequest.status == 200) {
    if (versionRequest.responseText != versionNum) {
      document.getElementById("newVersion").style.visibility = "visible";
    } else if (versionRequest.readyState == 4) {
      versionRequest.abort();
      versionRequest = null;
    }
  }
}